@@ -39,11 +39,13 @@ CREATE TABLE `call_record` (
   `imsi` varchar(32),
   `imei` varchar(15),
   `disconnect_cause` varchar(64),
+  `type` int(1) NOT NULL,
   PRIMARY KEY  (`id`),
   KEY `sim_name` (`sim_name`),
   KEY `time` (`time`),
   KEY `duration` (`duration`),
-  KEY `line_name` (`line_name`)
+  KEY `line_name` (`line_name`),
+  KEY `type` (`type`)
 ) ENGINE=MyISAM DEFAULT CHARSET=latin1;
 SET character_set_client = @saved_cs_client;
 
@@ -268,6 +270,10 @@ CREATE TABLE `sim` (
   `auto_reset_remain_s` int(11) NOT NULL default '60',
   `last_call_msg` varchar(256) NOT NULL,
   `count_limit_no_connect` BOOL NOT NULL,
+  `remark` varchar(32) NOT NULL,
+  `limit_sms` int(11) NOT NULL default '-1',
+  `remain_sms` int(11) NOT NULL default '-1',
+  `period_remain_sms` int(11) NOT NULL default '-1',
   PRIMARY KEY  (`id`),
   KEY `sim_name` (`sim_name`),
   KEY `line_name` (`line_name`)
@@ -377,7 +383,7 @@ SET character_set_client = @saved_cs_client;
 
 LOCK TABLES `system` WRITE;
 /*!40000 ALTER TABLE `system` DISABLE KEYS */;
-INSERT INTO `system` VALUES ('Simbank Server',3,1,20,10,110,0,5,0,1,'Unassigned (unallocated) number',0, 10, 15, 0, 10, 30, 0, 'Unassigned (unallocated) number');
+INSERT INTO `system` VALUES ('Simbank Server',3,1,20,10,112,0,5,0,1,'Unassigned (unallocated) number',0, 10, 15, 0, 10, 30, 0, 'Unassigned (unallocated) number');
 /*!40000 ALTER TABLE `system` ENABLE KEYS */;
 UNLOCK TABLES;
 
